@@ -11,16 +11,16 @@
 
 #include "akonadiconsole_debug.h"
 #include <QIcon>
-#include <akonadi/private/instance_p.h>
 #include <akonadi/private/dbus_p.h>
+#include <akonadi/private/instance_p.h>
 
 #include <QApplication>
 #include <QDBusConnection>
 #include <QDBusConnectionInterface>
 #include <QDBusInterface>
-#include <QStandardItemModel>
 #include <QDialogButtonBox>
 #include <QPushButton>
+#include <QStandardItemModel>
 #include <QVBoxLayout>
 
 InstanceSelector::InstanceSelector(const QString &remoteHost, QWidget *parent, Qt::WindowFlags flags)
@@ -28,12 +28,12 @@ InstanceSelector::InstanceSelector(const QString &remoteHost, QWidget *parent, Q
     , ui(new Ui::InstanceSelector)
     , m_remoteHost(remoteHost)
 {
-    auto *mainWidget = new QWidget(this);
-    auto *mainLayout = new QVBoxLayout(this);
+    auto mainWidget = new QWidget(this);
+    auto mainLayout = new QVBoxLayout(this);
     mainLayout->addWidget(mainWidget);
     ui->setupUi(mainWidget);
 
-    auto *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Close, this);
+    auto buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Close, this);
     QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
     okButton->setDefault(true);
     okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
@@ -52,9 +52,9 @@ InstanceSelector::InstanceSelector(const QString &remoteHost, QWidget *parent, Q
         }
         slotAccept();
     } else {
-        auto *model = new QStandardItemModel(this);
+        auto model = new QStandardItemModel(this);
         for (const QString &inst : insts) {
-            auto *item = new QStandardItem;
+            auto item = new QStandardItem;
             item->setText(inst.isEmpty() ? QStringLiteral("<global>") : inst);
             item->setData(inst, Qt::UserRole);
             model->appendRow(item);
@@ -72,7 +72,7 @@ InstanceSelector::~InstanceSelector()
 
 void InstanceSelector::slotAccept()
 {
-    if (ui->listView->model()) {   // there was something to select
+    if (ui->listView->model()) { // there was something to select
         const QModelIndexList selection = ui->listView->selectionModel()->selectedRows();
         if (selection.size() != 1) {
             return;
@@ -83,7 +83,7 @@ void InstanceSelector::slotAccept()
 
     qputenv("AKONADI_INSTANCE", m_instance.toUtf8());
     Akonadi::Instance::setIdentifier(m_instance);
-    auto *mWindow = new MainWindow;
+    auto mWindow = new MainWindow;
     if (!m_remoteHost.isEmpty()) {
         mWindow->setWindowTitle(QStringLiteral("Remote Akonadi Console (%1)").arg(m_remoteHost));
     } else if (!m_instance.isEmpty()) {
